function [OutJD,ObjVel]=otz_hjd(JD,ObjCoo)
% Description: Convert Julian Day (UTC) to Helicentric/Barycentric Julian
%              Day for geocentric observer.
% Input  : - Column vector of julian days (UTC time system).
%          - J2000.0 object coordinates, [RA, Dec], in radians.
% Output : - Heliocentric julian day (for geocentric observer).
%          - Heliocentric velocity component in object direction [km/sec]
%            (negative if object is moving toward Earth)
%            (it is opposite to E.O.Ofek original routine)
%
%     By : Eran O. Ofek                    Nov 1993
%    URL : http://weizmann.ac.il/home/eofek/matlab/
%      & : Olivier Thizy                   Sep 2016 -
%
% Example : [OutJD,ObjVel]=otz_hjd(JD,[RA Dec]);
% VV Cep le 20160101.50 :  [OutJD,ObjVel]=otz_hjd(2457389 ,[5.7450 1.1105])
%
% v1.0 / 20160903 - low resolution HJD calculation
% v1.1 / 20160905 - high resolution heliocentric calc
% Minor difference with ISIS V5.5.2, not sure if bug or not?
% Tested with original hjd() function with 'hh' option and it is OK
%
% Tested with MatLab2016a
% (c) Olivier Thizy
%

SEC_IN_DAY = 86400.0;
AU = 1.49597870691e8; % km;
c   = 299792.458; % km/s
% C in AU/day
C  = c*SEC_IN_DAY/AU;
N  = length(JD);
RAD = 180./pi;

% 'hh' option
DUT=0.;
DeltaT=0.;
JD_TT        = JD + double(DUT + DeltaT)/SEC_IN_DAY;

% [Coo,Vel]    = calc_vsop87(JD_TT, 'Earth', 'a', 'E');
%                function [Coo,Vel]=calc_vsop87(JD_TT, ObjectName, VSOP_Type, OutCooType);
% Local copy of calc_vsop87.m from http://weizmann.ac.il/home/eofek/matlab/
CooType = 'R';  % rectangular
System  = 'J';  % J2000.0
VSOP87_FileName = 'vsop87a.ear.mat';    

TJY = 365250.0;  % 1000 Julian years
LOD = SEC_IN_DAY;   % length of day [sec].
T = (JD_TT - double(2451545.0))/TJY;
Dt   = 1./(SEC_IN_DAY.*TJY);
Dts  = 1./(SEC_IN_DAY);
Tdt1 = T - Dt;
Tdt2 = T + Dt;


N = length(T);

% rotation matrix for transforming rectangular coordinates
% defined in dynamical ecliptic J2000.0 frame (i.e., VSOP87A, VSOP87E)
% to equatorial frame FK5 J2000.0
Rot_Dyn2FK5 = [+1.000000000000  +0.000000440360  -0.000000190919;
               -0.000000479966  +0.917482137087  -0.397776982902;
               +0.000000000000  +0.397776982902  +0.917482137087];

S_Col = 15;
K_Col = 16;
A_Col = 17;
B_Col = 18;
C_Col = 19;
P_Col = [3:14];
% read modified VSOP87 file
%VSOP87 = load(VSOvsop87aP87_FileName);
load(VSOP87_FileName);
eval(sprintf('VSOP87 = vsop87a;'));

Pow = mod(VSOP87(:,1),10);
Var = floor(mod(VSOP87(:,1),100)./10);
Obj = floor(mod(VSOP87(:,1),1000)./100);
Typ = floor(VSOP87(:,1)./1000);

%Coo1    = zeros(3,N);
Coo     = zeros(3,N);
Vel     = zeros(3,N);
Coo_dt1 = zeros(3,N);
Coo_dt2 = zeros(3,N);

for CooInd=1:1:3,
   J = find(Var==CooInd);
   for I=1:1:N,
      % calc coordinates per time
      Coo(CooInd,I) = sum((T(I).^(Pow(J))).*VSOP87(J,A_Col).*cos(VSOP87(J,B_Col) + VSOP87(J,C_Col).*T(I)));

      %Phi = sum(VSOP87(J,P_Col)*(Lambda(I,:).'),2);
      %Coo1(CooInd,I) = sum((T(I).^(Pow(J))).*(VSOP87(J,S_Col).*sin(Phi) + VSOP87(J,K_Col).*cos(Phi)));
      % calc coordinates for time+dt (for velocity)
      Coo_dt1(CooInd,I) = sum((Tdt1(I).^(Pow(J))).*VSOP87(J,A_Col).*cos(VSOP87(J,B_Col) + VSOP87(J,C_Col).*Tdt1(I)));
      Coo_dt2(CooInd,I) = sum((Tdt2(I).^(Pow(J))).*VSOP87(J,A_Col).*cos(VSOP87(J,B_Col) + VSOP87(J,C_Col).*Tdt2(I)));
   end
end

Vel = 0.5.*(Coo_dt2 - Coo_dt1)./Dts;
if (CooType=='S'),
   Coo(1:2,:) = (Coo(1:2,:)./(2.*pi) - floor(Coo(1:2,:)./(2.*pi))).*2.*pi;
   Ip = find(Coo(2,:)>pi);
   Coo(2,Ip) = Coo(2,Ip) - 2.*pi;
end

% --- convert to Equatorial FK5 J2000.0 ---
% rotation matrix for transforming rectangular coordinates
% defined in dynamical ecliptic J2000.0 frame (i.e., VSOP87A, VSOP87E)
% to equatorial frame FK5 J2000.0
Rot_Dyn2FK5 = [+1.000000000000  +0.000000440360  -0.000000190919;
    -0.000000479966  +0.917482137087  -0.397776982902;
    +0.000000000000  +0.397776982902  +0.917482137087];
% rotate coordinates
Coo = Rot_Dyn2FK5*Coo;
Vel = Rot_Dyn2FK5*Vel;
            
% END of local copy of calc_vsop87.m from http://weizmann.ac.il/home/eofek/matlab/


% ObjPos = cosined(ObjCoo).';
% Local copy of cosined.m from http://weizmann.ac.il/home/eofek/matlab/
% Description: Cosine direction transformation. Convert longitude
%              and latitude to cosine direction and visa versa.
Alpha = ObjCoo(:,1);
Delta = ObjCoo(:,2);
ObjPos = zeros(length(ObjCoo(:,1)),3);
ObjPos(:,1)     = cos(Alpha).*cos(Delta);
ObjPos(:,2)     = sin(Alpha).*cos(Delta);
ObjPos(:,3)     = sin(Delta);
ObjPos = ObjPos.';
% END of local copy of cosined.m from http://weizmann.ac.il/home/eofek/matlab/


DelJD = zeros(N,1);
ObjVel = zeros(N,1);
for I=1:1:N,
    EarthCoo = Coo(:,I);
    EarthVel = Vel(:,I);
    
    DelJD(I)  = norm(EarthCoo).*dot(ObjPos./norm(ObjPos),EarthCoo./norm(EarthCoo))./C;
    ObjVel(I) = -(norm(EarthVel).*dot(ObjPos./norm(ObjPos),EarthVel./norm(EarthVel)).*AU./SEC_IN_DAY);
end


OutJD = JD + DelJD;


% That's all folks!
