function otz_plot(varargin)
% otz_plot.m
%
% Display graph(s) of FITS astronomical spectrum/spectra
%
% Run "otz_plot -h" to get a short help & some exemples...
% 
% v1.0 / 20160816 - published in ARAS forum
% v1.1 / 20160817 - modified color handling + legend added, published on ARAS
% v1.2 / 20160820 - switched to struct for spectra X/Y; line styles added;
% scaling added (to be improved); use or rfitsinfo for better FITS header
% parsing (need both function/scripts to run it now); work on echelle spectra started
% v1.3 / 20160903 - -x (shift in A or km/s) added
% v1.4 / 20160905 - Link to CDS added (external function CDS_Infos.m), published on ARAS with dependencies
%                   Swap -y & -s option; add Epoch/Period option to -y for phase plots & obsolete -o option
% v1.5 / 20160909 - add file search pattern for first filename option
% 
% Dependencies (external functions to be used):
% rfitsinfo.m : get header & data from an astronomical spectrum (single HDU) FITS file
% CDS_Infos.m : get data from CDS server
% otz_hjd.m   : calculate heliocentric julian date & RV correction to apply
%
% Tested with MatLab R2016a
% (c) Olivier Thizy
%


% clean up some parameters
clear x;
clear y;
clear filename;
clear wavelengths;

% Option: -c 'scheme'
% ==>color(s) scheme for the graph(s)
% r, b...: red, blue; based on MatLab colors
param_c = 'brgmyck'; % plot spectra using this color scheme
% (b=blue, r=red, g=green, m=lagenta, y=yellow, c=cyan, k=black)
%
% Option: -d s[d[p[m
% ==>line style schme for the graph(s)
% s: solid, d = dashed line, p = dotted line, m= dash-dot line
param_d = 'sdpm'; % plot spectra using this line style scheme
LineStyle = {'s', '-'; 'd', '--'; 'p', ':'; 'm', '-.'}; % Cf plot function
%
% Option: -e # Ha Hb...
% ==>display echelle spectrum in multiple graphs
% # : Nb of graphs (negative: no full graph on top)
% Ha, Hb, etc.. : list of lines to show as well (same codes as -w option)
param_e = 0; % Nb of graphs; if negative, will not display the full spectrum on top
GraphTop = true; % Full spectrum top plot
GraphEchelle = 0; % echelle spectrum split in 'GraphEchelle' subplots
EchelleMarginPercent = 0; % [0-50] spectrum margin to add in each subgraphs (in % of the individual graph size)
GraphBottom = 0; % Nb of detailed graph (zoom on lines), bottom part of plot
%
% Option: -f filaname1 -f filename2 -f filename3...
% ==>allow multiple spectra on same graph
NbFiles = 1; % always one filename, first one doesn't need -f tag...
%
% Option: -h or -help
% ==>print help text
param_h = 0; % 0: doesn't print help
%
% Option: -l legend|X
% ==>add legend on graph
% X or x means no legend; 'legend' is similar to -t option and can include:
% d: date in YYYMMMDD.ddd format (Not implemented)
% D: date in DD-MMM-YYYY HH:MM:SS
% e: exposure in sec)
% i: instrument
% h: heliocentric JD -2400000
% j: julian date -2400000
% J: full julian date + 3 digits
% l: location site code
% L: full location name
% n: filename
% o: Observer code; O: Observer full name
% p: phase (if -p option is defined) (Not implemented)
% r: resolution power of the instrument
% t: target name (standard)
% T: object name from FITS file
% w: wavelength, no digit (when option -w is used)
% Exemple: -l do to display both date & observer code in legend
% (default is -l option is not defined by user)
%
param_l = 'Dwo'; % legend date + wavelength + observer code by default
%
% Option: -m linetype
% ==>mark set of lines marks on the graph
% Np for planetary nebulae
% Be for Be stars
% CV for Cataclysmic Variables
% O for O stars, B for B stars, A for A stars, F, G, K, M
% WN for Wolf-Rayet WN type
% WC for Wolf-Rayet WC type
param_m = 'none';
%
% Option: -o # OBSOLETE
% ==>if phenomenon is periodic, give the period (in days) so graph can be
% synch to it. Use in conjunction with -s & negative value (scale in
% Intensity shift)
%param_o = 0.0; % by default, no shift
%
% Option: -p pdf|png [X Y]
% ==>print PDF, PNG or none graph with X/Y size if provided (not
% implemented yet!)
param_p = 'none'; % print PDF file
%
% Option: -s X1 X2
% ==>rescale each graph using mean of intensity (Y axis) within (X1,X2: wavelength or velocities) mean
param_s = false;
param_s_w1 = 0;
param_s_w2 = 0;
%
% Option: -t title
% ==>type of title displayed: see -l option for legend (same codes)
param_t = 'tDeLiO'; % target / Date / exposure time / full location / instrument / full observer name
%
% Option: -w wavelength
% ==>plot in Radial Velocity using lambda wavelength
% ==> if used multiple times, plot different lines on same graph
c = double(300000); % speed of light
param_w = 0;
DefaultRV = 1000; % graph will be displayed by default within +/-DefaultRV limits
%
% Option: -x
% ==>apply a shift to the last graph (ie: can be used with different
% parameters, one for each graph/spectrum
% Use -x RV to use the RV of the target (see rfitsinfo.m) if known
% Use -x H to correct from heliocentric correction (obseleting -z then!)
param_x{1} = 'none'; % Type of shift, 1 = Graph/spectrum ID for the shift
param_x_value{1} = 0; % By default, no shift
param_x_unit{1} = 0; % 0=Angstroems; 1=km/sec
%
% Option: -y i|t|p scale (epoch period)
% i / intensity plot: scale = intensity shift between each graph (ex: 0.5)
% t / time plot: scale = days to intensity scaling factor (0.01 for exemple; 100days = 1 in intensity)
% p / phase plot: phase to intensity scaling factor, epoch in Heliocentric Julian Day, period in days
%    (for ex VV Cep: -y p 100 2438481 7430 / Ernst Pollmann & Wright, R.A.S.C. Jour., Vol 71, 1977)
param_y = 'n'; % by default, no shift
param_y_Ishift = 0.0;
param_y_Tscale = 0.0;
param_y_epoch = 0.0;
param_y_period = 0.0;
%

% Get parameters input
nVarargs = length(varargin);
Param = '';

Xlimit1 = -inf;
Xlimit2 = inf;
Ylimit1 = -inf;
Ylimit2 = inf;

NbFiles = 1;

% List of known lines, air wavelength
KnownLines = {'Ha','6562.801','50';'Hb','4861.363','50';'Hg','4340.47','50';'Hd','4101.74','50';
    'H5','3970.072','50';'H6','3889.049','50';'H7','3835.384','50';
    'Ha+He','6610', '100';'H&K','3950','70';'H','3968.47','50';'K','3933.66','50';
    'HeI', '6678','50';'D','5888','38';'D1','5895.92','30';'D2','5889.95','30';'D3','5875.618','40';
    'OIII','5006.843','50';};

% Source: http://classic.sdss.org/dr7/products/spectra/vacwavelength.html for Ha/Hb
% Conversion (TODO): AIR = VAC / (1.0 + 2.735182E-4 + 131.4182 / VAC^2 + 2.76249E8 / VAC^4)
% H-beta	4861.363
% [O III]	4958.911
% [O III]	5006.843
% [N II]	6548.05
% H-alpha	6562.801
% [N II]	6583.45
% [S II]	6716.44
% [S II]	6730.82
%


% Get first arguments which do not require a command -X before
LastArg = nVarargs;
for j = nVarargs:-1:1
    if strcmp(varargin{j}(1),'-')&&(size(str2num(varargin{j}),1) == 0)
        LastArg = j-1;
    end
end

switch LastArg
    case 0
        tmp = varargin{1};
        if  strcmp(tmp,'-h')|strcmp(tmp,'-help') % Special for HELP
            display('Tool to plot astronomical spectra in FITS & BeSS standard.');
            display('(c) Olivier Thizy / thizy@free.fr');
            display('v1.5 - 20150909 - tested with MatLab R2016a');
            display('---------------------------------');
            display('>otz_plot -h');
            display('Will give you this help...');
            display('>otz_plot -lines');
            display('Display the list of known lines with abreviations');            
            display('----- Options to select the files to display -----');
            display('>otz_plot ''filename.fits''');
            display('>otz_plot all');
            display('>otz_plot ''asdb_vvcep*.fits''');
            display('>otz_plot ?');            
            display('>otz_plot ''filename.fits'' -f ''file2.fits'' -f ''file3.fits''');
            display('----- Options to select the spectral domain to display -----');
            display('>otz_plot 6500 6600 ''filename.fits''');
            display('>otz_plot 6500 6600 0 5 ''filename.fits''');
            display('(here 0 5 are the Y-axis limits for the graphs)');
            display('>otz_plot Ha ''filename.fits''');
            display('(some codes can be used to quickly select the line to display; ''otz_plot -l'' to list the line codes)');
            display('>otz_plot ''filename.fits'' -w Ha -w Hb -w Hg');
            display('(the same line codes can be used for velocity plots)');
            display('-w (wavelength) options are the same as the line codes given by ''otz_plot -l''');
            display('----- Options for line color(s) & style(s) -----');
            display('>otz_plot 6500 6600 0 5 ''all'' -c bgr');
            display('-c (color) options: b=blue, r=red, g=green, m=lagenta, y=yellow, c=cyan, k=black');
            display('>otz_plot 6500 6600 0 5 ''all'' -d sp');
            display('-d (line style) options: s=solid, d=dash, p=dotted, m=dash-dot');
            display('----- Options for legend(s) -----');
            display('>otz_plot ''filename.fits'' -l X');
            display('-l (legend): you can specify what data you want to display in legend for each graph');            
            display('''legend'' are codes also used for the -t (title) option; they are:');
            display('   X or x means no legend');
%            display('d: date in YYYMMMDD.ddd format (Not implemented)');
            display('   D: date in DD-MMM-YYYY HH:MM:SS');
            display('   e: exposure in sec)');
            display('   i: instrument');
            display('   h: heliocentric JD -2400000');
            display('   j: julian date -2400000');
            display('   J: full julian date + 3 digits');
            display('   l: location site code');
            display('   L: full location name');
            display('   n: filename');
            display('   o: Observer code; O: Observer full name');
%            display('   p: phase (if -p option is defined) (Not implemented)');
            display('   r: resolution power of the instrument');
            display('   t: target name (standard)');
            display('   T: object name from FITS file');
            display('   w: wavelength, no digit (when option -w is used)');
            display('Exemple: ''-l Do'' to display both date & observer code in legend');
            display('(by default legend option is ''Dwo'': Date - wavelength - observer code');
            display('----- Options for main title -----');
            display('>otz_plot ''filename.fits'' -t o');
            display('-t (title): you can specify what data you want to display as title');
            display('X or x means no legend; ''title'' is similar to -l (legend) options');
            display('(by default title option is ''tDeLiO'': target / Date / exposure time / full location / instrument / full observer name');
            display('----- Options scaling Y-axis & X-axis -----');
            display('otz_plot -500 600 0 10 all -s 6540 6542 -w Ha');
            display('-s: rescale to 1 beteen 6540A & 6542A');
            display('>otz_plot ''filename.fits'' -x -18.3 -f ''filename2.fits'' -x 23');
            display('-x RV: use the object RV if known (see rfitsinfo.m / use CDS to get RV)');
            display('-x H: heliocentric correction (minor bug in calculation)');
            display('-x RVH: object RV *and* heliocentric correction');
            display('-x nA: apply a shift of ''n'' Angstroems');
            display('-x v: apply a shift of ''v'' in km/s');
            display('otz_plot -500 600 0 10 all -t object -y -0.01 -w Ha');
            display('-y i|t|p scale (epoch period) with options:');
            display('-y i scale / intensity plot; scale = intensity shift between each graph (ex: 0.5)');
            display('-y t scale / time plot; scale = days to intensity scaling factor (0.01 for exemple; 100days = 1 in intensity)');
            display('-y p scale epoch period / phase plot; phase to intensity scaling factor, epoch in Heliocentric Julian Day, period in days');
            display('(for ex VV Cep: -y p 100 2438481 7430) [=Emin / Wright, R.A.S.C. Jour., Vol 71, 1977]');
            display('(note that -y option is usually used in conjunction with -s option to ensure proper intensity scale)');
            display('otz_plot Ha all -t object -s 6540 6542 -y 0.5 -w Ha');
            display('-y: if positive, shifts all spectra by 0.5 Intensity');
            display('---------------------------------');
            display('I hope you''ll enjoy it !');            
            display(' ');
        end
        if  strcmp(tmp,'-l')|strcmp(tmp,'-lines') % Display lines abreviations
            display('Here are the known lines code to use, with wavelength in Angstroems & half width for graph display:');
            KnownLines
        end
            return;
    case 1
        filename{1} = varargin{1};
        NextVarN = 1;
    case 2
        Param = varargin{1};
        filename{1} = varargin{2};
        NextVarN = 2;
    case 3
        if varargin{2}(1) == '-'
            filename{1} = varargin{1};
            NextVarN = 1;
        else
            Xlimit1 = str2num(varargin{1});
            Xlimit2 = str2num(varargin{2});
            filename{1} = varargin{3};
            NextVarN = 3;
        end
    case 4
        Param = varargin{1};
        if varargin{3}(1) == '-'
            filename{1} = varargin{2};
            NextVarN = 2;
        else
            Ylimit1 = str2num(varargin{2});
            Ylimit2 = str2num(varargin{3});
            filename{1} = varargin{4};
            NextVarN = 4;
        end
    case 5
        Xlimit1 = str2num(varargin{1});
        Xlimit2 = str2num(varargin{2});
        Ylimit1 = str2num(varargin{3});
        Ylimit2 = str2num(varargin{4});
        filename{1} = varargin{5};
        NextVarN = 5;
    otherwise
        Xlimit1 = str2num(varargin{1});
        Xlimit2 = str2num(varargin{2});
        Ylimit1 = str2num(varargin{3});
        Ylimit2 = str2num(varargin{4});
        filename{1} = varargin{5};
        NextVarN = 6;
end

% get all FITS file from current directory if filename parameter is 'all'
FilesAll = false;
if strcmp(filename{1},'all')
    FilesAll = true;
    location = '.\';
    ds = datastore(location,'Type','image','IncludeSubfolders',false,'FileExtensions',{'.fit','.fits','.FIT','.FITS'});
%    ds = datastore(location,'Type','image','IncludeSubfolders',true,'FileExtensions',{'.fit','.fits','.FIT','.FITS'});
    % if multiple directories, can use {location1,location2,location3} syntax
    NbFiles = length(ds.Files);
    for k = 1:NbFiles
        filename{k} = char(ds.Files(k));
        param_x{k} = 'none';
    end
else
    Liste=ls(filename{1});
    if (size(Liste,1) > 1)
        NbFiles = size(Liste,1);
        for k = 1:NbFiles
            filename{k} = Liste(k,:);
            param_x{k} = 'none';
        end
    end
end

% if first filename is '?', then open a dialog box to get it
if filename{1}=='?'
    [FileName, PathName] = uigetfile ('*.fits');
    filename{1} = [PathName, FileName];
    param_x{1} = 'none';
end


% Parse the -X arguments
for k = NextVarN:nVarargs
    command=sscanf(varargin{k},'-%c');
    switch command
        case 'c' % color for the graph(s)
            param_c = varargin{k+1};
            k=k+1;
        case 'd' % line style for the graph(s)
            param_d = varargin{k+1};
            k=k+1;
        case 'e' % echelle spectra in multiple plots
            param_e = varargin{k+1};
            if param_e < 0
                GraphFull = true;
            else
                GraphFull = false;
            end
            GraphEchelle = abs(param_e);
            k=k+1;
            while (k <= nVarargs) && (strcmp(varargin{k}(1),'-') == false)
                for j = 1:size(KnownLines,1)
                    if strcmp(varargin{k},KnownLines(j,1))
                        GraphBottom = GraphBottom + 1;
                        EchelleWavelength{GraphBottom} = str2double(KnownLines(j,2));
                        EchelleWitdh{GraphBottom} = str2double(KnownLines(j,3));                        
                    end
                end
                k=k+1;
            end
        case 'f' % multiple files plot
            NbFiles = NbFiles + 1;
            filename{NbFiles} = varargin{k+1};
            param_x{NbFiles} = 'none';
            k=k+1;
        case 'l'
            param_l = varargin{k+1};
            k=k+1;
        case 'p'
            param_p = varargin{k+1};
            k=k+1;
        case 's'  % Y-axis scaling ('normalize') option
            param_s = true;
            if k == nVarargs
                param_s_w1 = 0;
                param_s_w2 = 0;
            else
                if strcmp(varargin{k+1}(1),'-')
                    param_s_w1 = 0;
                    param_s_w2 = 0;
                else
                    param_s_w1 = varargin{k+1};
                    param_s_w2 = varargin{k+2};
                    k=k+2;
                end
            end
        case 't' % title type
            param_t = varargin{k+1};
            k=k+1;
        case 'w' % Plot in velocity centered on wavelength(s)
            param_w = param_w + 1;
            if (k == nVarargs)
                if strcmp(Param,'')
                    wavelengths{param_w} = (Xlimit1 + Xlimit2)/2;                    
                else
                    for j = 1:size(KnownLines,1)
                        if strcmp(Param,KnownLines(j,1))
                            wavelengths{param_w} = str2double(KnownLines(j,2));
                        end
                    end            
                end
                k=k+1;
            else
                if strcmp(varargin{k+1}(1),'-')
                    wavelengths{param_w} = (Xlimit1 + Xlimit2)/2;
                    for j = 1:size(KnownLines,1)
                        if strcmp(Param,KnownLines(j,1))
                            wavelengths{param_w} = str2double(KnownLines(j,2));
                        end
                    end
                else
                    wavelengths{param_w} = str2double(varargin{k+1});
                    for j = 1:size(KnownLines,1)
                        if strcmp(varargin{k+1},KnownLines(j,1))
                            wavelengths{param_w} = str2double(KnownLines(j,2));
                            if Xlimit1 == -inf
                                Xlimit1 = double(-DefaultRV);
                            end
                            if Xlimit2 == inf
                                Xlimit2 = double(+DefaultRV);
                            end
                        end
                    end            
                end
                k=k+1;
            end
        case 'x' % shift for the X-axis (wavelength)
            if k == nVarargs
                display('ERROR: missing value/parameter after -x option');
                return;
            else
                param_X = varargin{k+1};
                k=k+2;
                switch param_X
                    case {'RV','H','RVH'}
                        if FilesAll
                            for jj = 1:NbFiles
                                param_x{jj} = param_X; % By default if no additional parameter is given
                                param_x_value{jj} = 0; % Value will be defined when reading the file (rfitsinfo)
                                param_x_unit{jj} = 1; % km/sec
                            end
                        else
                            param_x{NbFiles} = param_X; % By default if no additional parameter is given
                            param_x_value{NbFiles} = 0; % Value will be defined when reading the file (rfitsinfo)
                            param_x_unit{NbFiles} = 1; % km/sec
                        end
                    otherwise
                        if strfind(param_X,'A')
                            if FilesAll
                                for jj = 1:NbFiles
                                    param_x{jj} = 'A';
                                    [tmp, tmp2] = strtok(param_X,'A');
                                    param_x_value{jj} = str2num(tmp);
                                    param_x_unit{jj} = 0; % Angstroems
                                end
                            else
                                param_x{NbFiles} = 'A';
                                [tmp, tmp2] = strtok(param_X,'A');
                                param_x_value{NbFiles}=str2num(tmp);
                                param_x_unit{NbFiles} = 0; % Angstroems
                            end
                            
                        else
                            if FilesAll
                                for jj = 1:NbFiles
                                    param_x{jj} = 'V';
                                    param_x_value{jj} = str2num(param_X);
                                    param_x_unit{jj} = 1; % km/sec
                                end
                            else
                                param_x{NbFiles} = 'V';
                                param_x_value{NbFiles}=str2num(param_X);
                                param_x_unit{NbFiles} = 1; % km/sec
                            end
                        end;
                end
            end
        case 'y'
            param_y = varargin{k+1};
            k=k+1;
            switch param_y
                case 'i'
                    param_y_Ishift = str2double(varargin{k+1});
                    k=k+1;
                case 't'
                    param_y_Tscale = str2double(varargin{k+1});
                    k=k+1;
                case 'p'
                    param_y_Tscale = str2double(varargin{k+1});
                    param_y_epoch = str2double(varargin{k+2});
                    param_y_period = str2double(varargin{k+3});
                    k=k+3;
                otherwise
                    param_y = 'n'; % No shift by default or if error in parameters
            end
    end
end

% check if the line center is given in text/alias form
for k = 1:size(KnownLines,1)
    if strcmp(Param,KnownLines(k,1))
        if param_w == 0
            tmp1 = str2double(KnownLines(k,2));
            tmp2 = str2double(KnownLines(k,3));
            Xlimit1 = tmp1-tmp2;
            Xlimit2 = tmp1+tmp2;        
        else
            Xlimit1 = double(-DefaultRV);
            Xlimit2 = double(+DefaultRV);
        end
    end
end


% Browse all files selected
for k = 1:NbFiles
    % Extract FITS header and key infos from there
    Header = rfitsinfo(filename{k});
    Data = fitsread(filename{k});
    
    NbPoints = Header.NAXIS1;
    Origine = Header.WaveOrigin;
    Pas = Header.Dispersion;
    Objet = Header.Object;
    Date = Header.Date;
    Observateur = Header.Observer;
    ObserverCode = Header.ObserverCode;
    JDmid = Header.CalcJD;
    ExpTime = Header.Exposure;
    SiteObs = Header.SiteObs;
    SiteCode = Header.SiteCode;
    Instrument = Header.Instrument;
    
    dateGraph{k} = Header.Date; % used for legend
    ObserverGraph{k} = Header.Observer; % can be used for legend?
    ObjectGraph{k} = Header.Object; % can be used for legend?
    NbPointsGraph{k} = NbPoints;
    JDmidGraph{k} = JDmid;
    HJDGraph{k} = Header.HJD;
    OrigineGraph{k} = Origine;
    PasGraph{k} = Pas;
    DataGraph{k} = Data;
    HeaderGraph{k} = Header;
    GraphExpTime{k} = Header.Exposure;
    GraphSiteObs{k} = Header.SiteObs;
    GraphObserverCode{k} = Header.ObserverCode;
    GraphSiteCode{k} = Header.SiteCode;
    GraphInstrument{k} = Header.Instrument;
    RV{k}=Header.RV;
    VHel{k}=Header.VHel;
    
    
    

    % For echelle spectra, split in multiple plots
    NbPointsPerGraph{k} = idivide(NbPoints, int32(GraphEchelle), 'round');
    if EchelleMarginPercent <= 0
        SpectralDomainMargin{k} = 0;
    elseif EchelleMarginPercent > 50
        SpectralDomainMargin{k} = idivide(Xlimt2-Xlimit1, int32(2), 'round');
    else
        SpectralDomainMargin{k} = idivide(Xlimt2-Xlimit1, int32(100/EchelleMarginPercent), 'round');
    end

    if param_s_w1 == 0
        param_s_x1 = 1;
    else
        param_s_x1 = round(min([(NbPoints-1) max([1 (1 + (str2double(param_s_w1) - double(Origine)) / double(Pas))])]));
    end
    if param_s_w2 == 0
        param_s_x2 = NbPoints-1;
    else
        param_s_x2 = round(max([1 min([(NbPoints-1) (1 + (str2double(param_s_w2) - double(Origine)) / double(Pas))])]));
    end
    
    if param_s % Rescale the spectrum for that wavelength?
        Scale{k} = double(mean(Data (1,param_s_x1:param_s_x2)));
    else
        Scale{k} = 1.0;
    end

	UnsortedKey(k,1) = k;
    UnsortedKey(k,2) = JDmid; % data.CalcJD;

end


% Sort file by date if 'all' files (not if provided individually using -f)
if FilesAll
    SortedKey = sortrows(UnsortedKey,-[2]);
else
    SortedKey = UnsortedKey;
end


% Create specrum data: wavelength, intensity with Shift (-s option) &
% rescaling (-y option) is specified
for index=1:NbFiles
    k = SortedKey(index,1);

    % Calculate vertical (intensity) shift to apply
    YShift{k} = 0.0;
    switch param_y
        case 'i'
            YShift{k} = double(k-1)*double(param_y_Ishift);
        case 't'
            YShift{k} = (JDmidGraph{k} - JDmidGraph{SortedKey(1,1)})*double(param_y_Tscale);
        case 'p'
            if param_y_period ~= 0
                if param_y_epoch == 0
                    YShift{k} = -1 + rem((HJDGraph{k} - HJDGraph{SortedKey(1,1)}),param_y_period) / param_y_period * double(param_y_Tscale);
                else
                    YShift{k} = -1 + rem((HJDGraph{k} - param_y_epoch),param_y_period) / param_y_period * double(param_y_Tscale);
                end
            end
    end        
            
    Spectrum{k}.XShift = double(0);
    switch param_x{k}
        case 'RV'
            Spectrum{k}.XShift = -double(RV{k});
        case 'H'
            Spectrum{k}.XShift = -double(VHel{k});
        case 'RVH'
            Spectrum{k}.XShift = -double(RV{k}) - double(VHel{k});
        case 'V'
            Spectrum{k}.XShift = double(param_x_value{k});
    end
    
    for a = 1 : NbPointsGraph{k}
        Lambda = OrigineGraph{k} + double(a-1) * PasGraph{k};
        if strcmp(param_x{k},'A')
            Lambda = Lambda + double(param_x_value{k});
        end
        Spectrum{k}.x(a) = double(Lambda);
        Spectrum{k}.y(a) = YShift{k} + DataGraph{k} (1,a) / Scale{k};
    end
end


% display graph / open an half screen figure
figure('units','normalized','outerposition',[0.1 0.1 .5 .5])

NGraph = 1;
ColorIndex = 1;
LineStyleIndex = 1;

% Top graph
% For each spectrum
for index = 1:NbFiles
    k = SortedKey(index,1);
    if param_w == 0
        if param_e == 0
            % change line color & style based on input
            for j = 1:size(LineStyle,1)
                if strcmp(param_d(LineStyleIndex),LineStyle(j,1))
                    Style = strcat(LineStyle(j,2),param_c(ColorIndex));
                end
            end
            ColorIndex = ColorIndex + 1;
            if ColorIndex > size(param_c,2)
                ColorIndex = 1;
                LineStyleIndex = LineStyleIndex + 1;
                if LineStyleIndex > size(param_d,2)
                    LineStyleIndex = 1;
                end
            end
            % Color = param_c(1+rem(NGraph,size(param_c,2)));

            %%% PLOT the spectrum...
            Graph{NGraph} = plot(Spectrum{k}.x, Spectrum{k}.y, Style{1});

            % Define Graph legend (based on -l option)
            % X means no legend; 'legend' is similar to -t option and can include:
            if ~strcmp(param_l,'X') && ~strcmp(param_l,'x') % no legend;
                GraphLegend{NGraph} = '';
                for LL=1:size(param_l,2)
                    switch param_l(LL)
                        case 'o' % o: Observer code
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' HeaderGraph{k}.ObserverCode];
                        case 'O' % O: Observer full name
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' (c) ' HeaderGraph{k}.Observer];
                        case 'n' % n: filename
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' filename{k}];
                        case 'd' % d: mid JD date in YYYMMMDD.ddd format NOT IMPLEMENTED YET
                            % GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' ];
                        case 'D' % D: date in DD-MMM-YYYY HH:MM:SS
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' - ' datestr(dateGraph{k})];
                        case 'e' % e: exposure in sec)
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' - ' num2str(GraphExpTime{NbFiles}) 's'];
                        case 'l' % l: location site code
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' @ ' HeaderGraph{k}.SiteCode];
                        case 'L' % L: full location name
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' @ ' HeaderGraph{k}.SiteObs];
                        case 'i' % i: instrument
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' w/ ' HeaderGraph{k}.Instrument];
                        case 'r' % r: resolution power
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' HeaderGraph{k}.Resolution];
                        case 'j' % j: julian date -2400000
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' num2str(JDmidGraph{k}-2400000,'%0.3f')];
                        case 'J' % J: full julian date + 3 digits
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' num2str(JDmidGraph{k},'%0.3f')];
                        case 'h' % h: heliocentric JD -2400000
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' num2str(HeaderGraph{k}.HJD-2400000,'%0.3f')];
                        case 'H' % h: heliocentric JD
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' num2str(HeaderGraph{k}.HJD,'%0.3f')];
                        case 'p' % p: phase (if -p option is defined) / NOT IMPLEMENTED YET
                            % GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' ];
                        case 'w' % w: wavelength, no digit (only when option -w is used for now)
                            % GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' ];
                        case 't' % t: target name (standardized if possible)
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' | ' HeaderGraph{k}.Object];
                        case 'T' % T: full object name from FITS file
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' | ' HeaderGraph{k}.ObjName];
                    end
                end
            end
            NGraph = NGraph + 1;
            hold on;
        else
            % echelle spectra multi-plotting TO DO !!!
        end
    else
        % For each central wavelength
        for nw = 1:param_w
            for j = 1:size(Spectrum{k}.x,2)
                Spectrum{k}.w(j) = (Spectrum{k}.x(j)-wavelengths{nw})*c/wavelengths{nw} + Spectrum{k}.XShift;
            end
            % TO ADD HERE: RESCALE FOR EACH WAVELENGTH PLOT CONTINUUM
            % WITHIN GIVEN RANGE...
            for j = 1:size(LineStyle,1)
                if strcmp(param_d(LineStyleIndex),LineStyle(j,1))
                    Style = strcat(LineStyle(j,2),param_c(ColorIndex));
                end
            end
            ColorIndex = ColorIndex + 1;
            if ColorIndex > size(param_c,2)
                ColorIndex = 1;
                LineStyleIndex = LineStyleIndex + 1;
                if LineStyleIndex > size(param_d,2)
                    LineStyleIndex = 1;
                end
            end
            
            %%% PLOT the graph for spectrum #k, wavelength #nw
            Graph{NGraph} = plot(Spectrum{k}.w, Spectrum{k}.y, Style{1});
            % TimeSerie=ones(1,size(Spectrum{k}.y,2))*YShift{k};
            % Graph{NGraph} = waterfall(TimeSerie, Spectrum{k}.w, Spectrum{k}.y, Style{1}); % Too big to work in MatLab !!!

            % Define Graph legend (based on -l option)
            % X means no legend; 'legend' is similar to -t option and can include:
            if ~strcmp(param_l,'X') && ~strcmp(param_l,'x') % no legend;
                GraphLegend{NGraph} = '';
                for LL=1:size(param_l,2)
                    switch param_l(LL)
                        case 'o' % o: Observer code
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' HeaderGraph{k}.ObserverCode];
                        case 'O' % O: Observer full name
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' (c) ' HeaderGraph{k}.Observer];
                        case 'n' % n: filename
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' filename{k}];
                        case 'd' % d: mid JD date in YYYMMMDD.ddd format
                            %GraphLegend{NGraph} = [GraphLegend{NGraph} ' - ' ];
                        case 'D' % D: date in DD-MMM-YYYY HH:MM:SS
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' - ' datestr(dateGraph{k})];
                        case 'e' % e: exposure in sec)
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' num2str(GraphExpTime{NbFiles}) 's'];
                        case 'l' % l: location site code
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' @ ' HeaderGraph{k}.SiteCode];
                        case 'L' % L: full location name
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' @ ' HeaderGraph{k}.SiteObs];
                        case 'i' % i: instrument
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' w/ ' HeaderGraph{k}.Instrument];
                        case 'r' % r: resolution power
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' HeaderGraph{k}.Resolution];
                        case 'j' % j: julian date -2400000
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' num2str(JDmidGraph{k}-2400000,'%0.3f')];
                        case 'J' % J: full julian date + 3 digits
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' num2str(JDmidGraph{k},'%0.3f')];
                        case 'h' % h: heliocentric JD -2400000
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' num2str(HeaderGraph{k}.HJD-2400000,'%0.3f')];
                        case 'H' % h: heliocentric JD
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' num2str(HeaderGraph{k}.HJD,'%0.3f')];
                        case 'p' % p: phase (if -p option is defined) / NOT IMPLEMENTED YET
                            % GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' ];
                        case 'w' % w: wavelength, no digit (only when option -w is used for now)
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' num2str(wavelengths{nw},'%0.0f')];
                        case 't' % t: target name (standardized if possible)
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' | ' HeaderGraph{k}.Object];
                        case 'T' % T: full object name from FITS file
                            GraphLegend{NGraph} = [GraphLegend{NGraph} ' | ' HeaderGraph{k}.ObjName];
                    end
                end
            end
            NGraph = NGraph + 1;
            hold on;
        end
    end
end

% Define X & Y limits for the graph
x_limit = [Xlimit1 Xlimit2];
xlim(x_limit)
y_limit = [Ylimit1 Ylimit2];
ylim(y_limit)

if ~strcmp(param_l,'X') && ~strcmp(param_l,'x')
    legend(GraphLegend);
end

% Display title above the first graph with last file data
if ~strcmp(param_t,'X') && ~strcmp(param_t,'x') % no legend;
    Titre2 = '';
    for LL=1:size(param_t,2)
        switch param_t(LL)
            case 'o' % o: Observer code
                Titre2 = [Titre2 ' / ' HeaderGraph{k}.ObserverCode];
            case 'O' % O: Observer full name
                Titre2 = [Titre2 ' (c) ' HeaderGraph{k}.Observer];
            case 'n' % n: filename
                Titre2 = [Titre2 ' / ' filename{k}];
            case 'd' % d: mid JD date in YYYMMMDD.ddd format
                % Titre2 = [Titre2 ' - ' ];
            case 'D' % D: date in DD-MMM-YYYY HH:MM:SS
                Titre2 = [Titre2 ' - ' datestr(dateGraph{k})];
            case 'e' % e: exposure in sec)
                Titre2 = [Titre2 ' / ' num2str(GraphExpTime{NbFiles}) 's'];
            case 'l' % l: location site code
                Titre2 = [Titre2 ' @ ' HeaderGraph{k}.SiteCode];
            case 'L' % L: full location name
                Titre2 = [Titre2 ' @ ' HeaderGraph{k}.SiteObs];
            case 'i' % i: instrument
                Titre2 = [Titre2 ' w/ ' HeaderGraph{k}.Instrument];
            case 'r' % r: resolution power
                Titre2 = [Titre2 ' / ' HeaderGraph{k}.Resolution];
            case 'j' % j: julian date -2400000
                Titre2 = [Titre2 ' / ' num2str(JDmidGraph{k}-2400000,'%0.3f')];
            case 'J' % J: full julian date + 3 digits
                Titre2 = [Titre2 ' / ' num2str(JDmidGraph{k},'%0.3f')];
            case 'h' % h: heliocentric JD -2400000
                Titre2 = [Titre2 ' / ' num2str(HeaderGraph{k}.HJD-2400000,'%0.3f')];
            case 'H' % h: heliocentric JD
                Titre2 = [Titre2 ' / ' num2str(HeaderGraph{k}.HJD,'%0.3f')];
            case 'p' % p: phase (if -p option is defined) / NOT IMPLEMENTED YET
                % GraphLegend{NGraph} = [GraphLegend{NGraph} ' / ' ];
            case 'w' % w: wavelength, no digit (only when option -w is used for now)
                % Titre2 = [Titre2 ' / ' num2str(wavelengths{nw},'%0.0f')];
            case 't' % t: target name (standardized if possible)
                Titre2 = [Titre2 ' | ' HeaderGraph{k}.Object];
            case 'T' % T: full object name from FITS file
                Titre2 = [Titre2 ' | ' HeaderGraph{k}.ObjName];
        end
    end
end

if strcmp(Titre2,'')
else
    title(Titre2, 'Interpreter','none');
end

if param_w == 0
    xlabel('Wavelenght in ');
else
    xlabel('Velocity in km/s');
end
ylabel('Relative flux');


% save graph in PDF & PNG using 1st filename
[pathstr,name,ext] = fileparts(filename{1});
orient landscape;
outputfile = ['graph' name];
switch param_p
    case 'pdf'
        print (outputfile, '-painters', '-dpdf', '-fillpage');
    case 'png'
        orient portrait;
        print (outputfile, '-dpng');
end

% That's all folks !
