function Header=rfitsinfo(File)

% RFITSINFO	Read FITS file header
%	Specific for astronomical spectra, mainly amateur ones
%   
%
%	RFITSINFO('file') reads a file written in FITS format and returns
%	all the relevant information in the header.
%
% v1.0 / 20160901
% Version used for v1 of ARAS dataBase using MatLab
% v1.1 / 20160905
% RA/Dec and some other star informations added, link CDS
%
% Tested with MatLab2016a
% (c) Olivier Thizy
%

% TO DO:
% ======
%
% ==> Heliocentric JD calculation
% using the astronomy & astrophysics package for Matlab (Ofek 2014)
% Cf: http://adsabs.harvard.edu/abs/2014ascl.soft07005O
%
% Pour VV Cep par exemple:
% ra = (21+(56+39.14385/60)/60)/12*pi
% dec = (63+(37+32.0174/60)/60)/180*pi
% jd = julian date
% [OutJD,ObjVel] = hjd(jd,[ra dec],'hh')
% showresult = sprintf('%0.6f',OutJD)
%
% ==> Calculate Heliocentric RV correction
% (to be done in rfitsinfo ?)
%
% ==> object name conversion & RA/DEC list
% *** ARASstars: table listing stars with key infos:VV Cep, RA, Dec, Vmag,
% SpType, ARASGroup, ARASSubGroup... (ext. TEXT file?)
% *** ARASstarsEQ: table of aliases for stars/objects; ex: VV Cep, VV_Cep,
% vvcep...  (ext. TEXT file?)
% Change the ObsCode conversion using a table structure (ext. TEXT file?)
% Change the ObsSite conversion using a table structure (ext. TEXT file?)
% Add in output data structure:
% --> RA, RA_d, RA_m, RA_s
% --> DEC, DEC_d, DEC_m, DEC_s
% --> Vmag, SpecType
%


H=fitsinfo(File);
Data = fitsread(File);
%Header.filename = File;


% searching for key header values
if max(size(H.Contents)) == 1
    kwd = H.PrimaryData.Keywords ;
elseif max(size(H.Contents)) > 3
    kwd = [H.PrimaryData.Keywords;H.Image(max(size(H.Contents))-2).Keywords];
else
    kwd = H.PrimaryData.Keywords ;
end

HeaderMax = max(size(kwd));

% Set criteria to 0; will be set to 1 when keyword is found...
WaveOrigin = 0;
Dispersion = 0;
Object = 0;
Date = 0;
DateEnd = 0;
JD = 0;
CalcJD = 0;
MidHJD = 0;
Exposure = 0;
ExpTimeTotal = 0;
Observer = 0;
Site = 0;
Instrument = 0;
NAXIS1 = 0;
Resolution = 0;
VHel = 0;
Header.VHel = 0; % unknown by default... TODO: calculate it if not provided in FITS header
Header.VHelValid = 0; % 0: unknown; 1: known *or* calculated; -1: known but mismatch between FITS header & calculated value
Header.RARad = 0;
Header.DecRad = 0;


% Extrait certaines donnes de l'entete fit
for l=1:HeaderMax
    k = kwd{l,1};
    kc = kwd{l,2};
    kt = kwd{l,3};
    
    switch k
        % CALIBRATION & REDUCTION data
        case 'NAXIS1'
            Header.NAXIS1 = kwd {l,2};
            NAXIS1= 1;
        case 'CRVAL1'
            Header.WaveOrigin = kwd {l,2};
            WaveOrigin = 1;
        case 'CDELT1'
            Header.Dispersion = kwd {l,2};
            Dispersion = 1;
        case 'BSS-VHEL'
            Header.VHel = 0; % Heliocentric correction already applied on spectrum
            VHel = 1;
        case 'BSS-RQVH'
            Header.VHel = str2num(kwd {l,2});
            VHel = 1;
            % Note on BSS-VHEL & BSS-RQVH from BeSS spectra (cf BeSS file specs)
            % About the heliocentric velocity correction.
            % The convention used for the heliocentric velocity correction (Vhelio)
            % is the redshift one : it is the escape velocity, positive if the Earth
            % is going to the opposite direction to the star.
            %       Lambda_corrected = Lambda_initial * (1 - Vhelio / c)
            % where c is the velocity of light
            % Two keywords are used for the heliocentric velocity correction : the 'actual correction'
            % (in BSS_VHEL, mandatory) and the 'correction to be applied' (in BSS_RQVH, optional).
            % The 'correction to be applied' is calculated from the stellar coordinates,
            % observing site coordinates, and observing date & time.
            % If the velocity is not heliocentrically corrected (preferred), the 'actual correction'
            % keyword (BSS_VHEL) contains 0
            % VHel & RV convention is th same as BeSS (and same as CDS/Simbad)
            
        % OBJECT data
        case 'RA' % works for spectra from BeSS / TODO: more validity check there + conv TXT
            if isnumeric(kwd {l,2})
                Header.RARad = kwd {l,2};
            else
                Header.RARad = str2num(kwd {l,2});
            end
        case 'DEC' % works for spectra from BeSS / TODO: more validity check on RA (rad / deg?) + conv TXT
            if isnumeric(kwd {l,2})
                Header.DecRad = kwd {l,2};            
            else
                Header.DecRad = str2num(kwd {l,2});            
            end
        case {'OBJNAME', 'OBJECT'}
            Header.Object = kwd {l,2};
            Header.ObjName = kwd {l,2}; % Original name from FITS file
            Object = 1;
            switch Header.Object % Convert Object name to standard name for more consistent display/use
                case {'PCyg', 'p_cygni','P Cyg', 'pcyg', 'p cyg', '34 cyg', '34 Cyg', '34_cyg', '34_Cyg', '               P Cyg', 'P CYG'}
                    Header.Object = 'P Cyg';
                    Header.Campaign = 'LBV';
                case {'SS443','SS433', 'SS 433', '01_ss433', 'ss433', '__ss433', 'ss-433-', 'ss433-', 'SS433_', 'SS433V1', 'SS433 V2'}
                    Header.Object = 'SS 433';
                    Header.Campaign = 'Micro Quasars';
                case {'Cygnus X-1', 'cygnus x-1', 'Cygnus x-1', 'V1357Cyg', 'CygnusX-1', 'CygnusX1', '__cygx-1', 'CygX1', 'Cyg X1', 'CYNGUSX'}
                    Header.Object = 'Cygnus X-1';
                    Header.Campaign = 'Micro Quasars';
                case {'Scorpius X-1', 'Sco C-1'}
                    Header.Object = 'Sco X-1';
                    Header.Campaign = 'Micro Quasars';
                case {'LS5039', 'LS 5039'}
                    Header.Object = 'LS5039';
                    Header.Campaign = 'Micro Quasars';
                case {'V4641 Sgr'}
                    Header.Object = 'V4641 Sgr';
                    Header.Campaign = 'Micro Quasars';
                case {'VVCep', 'VVcep', 'vvcep', 'VV Cep', 'VV cep', 'vv cep', 'vv_cep', '              VV Cep','VV Cep_5min','VV Cep_20sec'}
                    Header.Object = 'VV Cep';
                    Header.Campaign = 'VV Cep Stars';
                case {'31cyg', '31Cyg', '31 cyg', '31 Cyg', '31_cyg', '31_Cyg'}
                    Header.Object = '31 Cyg';
                    Header.Campaign = 'VV Cep Stars';
                case {'32cyg', '32Cyg', '32 cyg', '32 Cyg', '32_cyg', '32_Cyg'}
                    Header.Object = '32 Cyg';
                    Header.Campaign = 'VV Cep Stars';
                case {'zet Aur', 'zetAur', 'zet aur', 'zeta Aur', 'zeta aur', 'zet_Aur', 'zet_aur'}
                    Header.Object = 'zet Aur';
                    Header.Campaign = 'VV Cep Stars';
                case {'eps Aur', 'epsAur', 'eps aur', 'epsilon Aur', 'espilon aur', 'eps_Aur', 'eps_aur', 'Epsilon Aur'}
                    Header.Object = 'eps Aur';
                    Header.Campaign = 'VV Cep Stars';
                case {'alp Boo'}
                    Header.Object = 'alp Boo';
                    Header.Campaign = 'none';
                case {'HD 192640', 'hd 192640', 'HD192640', 'hd192640'}
                    Header.Object = 'HD 192640';
                    Header.Campaign = 'MILES';
                case {'QR Vul'}
                    Header.Object = 'QR Vul';
                    Header.Campaign = 'BeSS';
                    
                    %            case {'', '', '', '', ''}
                    %                Header.Object = '';
                otherwise
                    Header.Campaign = ''; % Unknown...
                    Header.RA = ''; % Unknown...
                    Header.Dec = ''; % Unknown...
                    Header.RARad = 0; % Unknown...
                    Header.DecRad = 0; % Unknown...
                    Header.MagV = 0; % Unknown...
                    Header.RV = 0; % Unknown...
                    Header.SpecType = ''; % Unknown...
            end
            CDS=CDS_Infos(Header.Object); % Get additional information from CDS server
            if CDS.Valid
                % Header.Object = CDS.Name;
                Header.RA = CDS.RA;
                Header.RARad = CDS.RARad;
                Header.Dec = CDS.Dec;
                Header.DecRad = CDS.DecRad;
                Header.SpectralType = CDS.SpectralType;
                Header.MagB = CDS.MagV;
                Header.MagV = CDS.MagV;
                Header.MagR = CDS.MagV;
                Header.RV = CDS.RV;
            end

        % OBS DATE & EXPOSURE TIME data
        case 'DATE-OBS'
            Date = 1;
            if length(kwd {l,2}) == 17
                Header.Date = datetime(kwd {l,2},'InputFormat','uuuuMMdd''T''HH:mm:ss','TimeZone','UTC');
            elseif length(kwd {l,2}) == 18
                Header.Date = datetime(kwd {l,2},'InputFormat','uuuuMMdd''T:''HH:mm:ss','TimeZone','UTC');
            elseif length(kwd {l,2}) == 19
                if strcmp(kwd{l,2}(14),'-')
                    Header.Date = datetime(kwd {l,2},'InputFormat','uuuu-MM-dd''T''HH-mm:ss','TimeZone','UTC');
                else
                    Header.Date = datetime(kwd {l,2},'InputFormat','uuuu-MM-dd''T''HH:mm:ss','TimeZone','UTC');
                end
            elseif  length(kwd {l,2}) == 20
                Header.Date = datetime(kwd {l,2},'InputFormat','uuuu-MM-dd''T''HH:mm:ss.','TimeZone','UTC');
            elseif  length(kwd {l,2}) == 21
                Header.Date = datetime(kwd {l,2},'InputFormat','uuuu-MM-dd''T''HH:mm:ss.S','TimeZone','UTC');
            elseif  length(kwd {l,2}) == 22
                Header.Date = datetime(kwd {l,2},'InputFormat','uuuu-MM-dd''T''HH:mm:ss.SS','TimeZone','UTC');
            elseif  length(kwd {l,2}) >= 23
                Header.Date = datetime(kwd {l,2},'InputFormat','uuuu-MM-dd''T''HH:mm:ss.SSS','TimeZone','UTC');
            elseif  isempty(kwd {l,2})
                Header.Date = kwd {l,2};
                Date = 0;
            end
        case 'DATE-END'
            DateEnd = 1;
            if length(kwd {l,2}) == 17
                Header.DateEnd = datetime(kwd {l,2},'InputFormat','uuuuMMdd''T''HH:mm:ss','TimeZone','UTC');
            elseif length(kwd {l,2}) == 18
                Header.DateEnd = datetime(kwd {l,2},'InputFormat','uuuuMMdd''T:''HH:mm:ss','TimeZone','UTC');
            elseif length(kwd {l,2}) == 19
                Header.DateEnd = datetime(kwd {l,2},'InputFormat','uuuu-MM-dd''T''HH:mm:ss','TimeZone','UTC');
            elseif  length(kwd {l,2}) == 20
                Header.DateEnd = datetime(kwd {l,2},'InputFormat','uuuu-MM-dd''T''HH:mm:ss.','TimeZone','UTC');
            elseif  length(kwd {l,2}) == 21
                Header.DateEnd = datetime(kwd {l,2},'InputFormat','uuuu-MM-dd''T''HH:mm:ss.S','TimeZone','UTC');
            elseif  length(kwd {l,2}) == 22
                Header.DateEnd = datetime(kwd {l,2},'InputFormat','uuuu-MM-dd''T''HH:mm:ss.SS','TimeZone','UTC');
            elseif  length(kwd {l,2}) >= 23
                Header.DateEnd = datetime(kwd {l,2},'InputFormat','uuuu-MM-dd''T''HH:mm:ss.SSS','TimeZone','UTC');
            elseif  isempty(kwd {l,2})
                Header.DateEnd = kwd {l,2};
                DateEnd = 0;
            end
        case {'DATE-JD','JD-OBS'}
            Header.JD = kwd {l,2};
            JD = 1;
        case {'MJD-OBS'}
            Header.JD = 2400000 + kwd {l,2};
            JD = 1;
        case 'MID-HJD'
            Header.MidHJD = kwd {l,2};
            MidHJD = 1;
        case {'EXPTIME','EXPOSURE'} % Exposure to light / TBD: check when EXPTIME ~= EXPOSURE !!!
            if isnumeric(kc) % Some FITS file have EXPOSURE numeric and EXPTIME string
                Header.Exposure = kwd {l,2};
                Exposure = 1;
            end
        case 'EXPTIME2' % Total exposure duration (including in-between read-out time)
            Header.ExpTimeTotal = kwd {l,2};
            ExpTimeTotal = 1;
            
        % OBSERVER data
        case 'OBSERVER'
            Header.Observer = kwd {l,2};
            Observer = 1;
            switch Header.Observer
                case 'Paolo Berardi'
                    Header.ObserverCode = 'BER';
                case {'cbuil','cbuil   '}
                    Header.ObserverCode = 'CBU'; % To be confirmed !!!
                case {'Christian Kreider','ChK     ','ChK'}
                    Header.ObserverCode = 'CHK';
                case 'Ch. REVOL'
                    Header.ObserverCode = 'CRE';
                case {'D.Boyd  ','D.Boyd'}
                    Header.ObserverCode = 'DBO';
                    %Header.SiteCode = 'WCO-UK';
                case {'DongLi  ','DongLi'}
                    Header.ObserverCode = 'DLI';
                case 'ETB'
                    Header.ObserverCode = 'EBE';
                case 'fboubault'
                    Header.ObserverCode = 'FBO';
                case {'fteyssier','Francois Teyssier','FTeyssier'}
                    Header.ObserverCode = 'FMT';
                case 'kgraham '
                    Header.ObserverCode = 'GKA';
                case {'A. Garcia  J. Guarro','J. Guarro'}
                    Header.ObserverCode = 'JGU'; % To be confirmed !!!
                case 'JJ Broussat'
                    Header.ObserverCode = 'JJB';
                case 'Jacques Montier'
                    Header.ObserverCode = 'JMO';
                case {'JEdlin  ','JEdlin'}
                    Header.ObserverCode = 'JPE';
                case {'JP MASVIEL','JP Masviel'}
                    Header.ObserverCode = 'JPM'; % To be confirmed !!!
                case {'JPNougayrede','jpnoug'}
                    Header.ObserverCode = 'JPN';
                case {'tlester','tlester '}
                    Header.ObserverCode = 'LES';
                case 'Malcolm Locke'
                    Header.ObserverCode = 'MLO'; % To be confirmed !!!
                case {'Nico Montigiani, Massimiliano Mannucci','Nico Montigiani, Massimiliano Mannucci, Lapo Ferrini'}
                    Header.ObserverCode = 'NMO'; % To be confirmed !!!
                case {'Olivier garde','Olivier Garde'}
                    Header.ObserverCode = 'OGA';
                    % Header.SiteCode = 'OTO-FR';
                case {'Olivier THIZY','Olivier Thizy','Olivier Thizy, Ribeiro J','Olivier Thizy, MASVIEL','Olivier THIZY, Christian BUIL, Valerie DESNOUX, Michel PUJOL','Olivier Thizy, A Lopez, P Dubreuil, G Kobber'}
                    Header.ObserverCode = 'OTH';
                case 'Pollmann'
                    Header.ObserverCode = 'POL';
                    % Header.SiteCode = 'LEV-DE';
                case {'Pierre DUBREUIL','Pierre Dubreuil'}
                    Header.ObserverCode = 'PDU'; % To be confirmed !!!
                case {'PSO','psomogyi'}
                    Header.ObserverCode = 'PSO';
                case 'Leadbeater'
                    Header.ObserverCode = 'RLE'; % To be confirmed !!!
                case 'S. Charbonnel'
                    Header.ObserverCode = 'SCH'; % To be confirmed !!!
                case 'TBohlsen'
                    Header.ObserverCode = 'TBO'; % To be confirmed !!!
                case 'Umberto Sollecchia'
                    Header.ObserverCode = 'USO'; % To be confirmed !!!
                case 'Buchheim'
                    Header.ObserverCode = 'RBU'; % To be confirmed !!!
                case ''
                    Header.ObserverCode = ''; % To be confirmed !!!
                case ''
                    Header.ObserverCode = ''; % To be confirmed !!!
                otherwise
                    Header.ObserverCode = '---';
            end
            
        % SITE LOCATION data
        case {'BSS_SITE','ORIGIN','SITENAME'}
            Header.SiteObs = kwd {l,2};
            Site = 1;
            switch Header.SiteObs
                case {'Saint-Veran','AQ-St Veran'}
                    Header.SiteCode = 'AAQ-FR'; % To be confirmed !!!
                case 'C.A.L.C'
                    Header.SiteCode = 'ALC-FR'; % To be confirmed !!!
                case {'AMPERE LYON(FR)','AMPERE(Lyon)'}
                    Header.SiteCode = 'AMP-FR'; % To be confirmed !!!
                case 'Lac Appolinaire'
                    Header.SiteCode = 'APP-FR'; % To be confirmed !!!
                case 'LAquila'
                    Header.SiteCode = 'AQL-IT'; % To be confirmed !!!
                case 'Arnprior_ON_CA'
                    Header.SiteCode = 'ARN-CA'; % To be confirmed !!!
                case 'Aspremont (06)'
                    Header.SiteCode = 'ASP-FR'; % To be confirmed !!!
                case 'Bellavista Obs. L'
                    Header.SiteCode = 'BEL-IT'; % To be confirmed !!!
                case 'Observatoire du CALA'
                    Header.SiteCode = 'CAL-FR'; % To be confirmed !!!
                case 'Castanet'
                    Header.SiteCode = 'CAS-FR'; % To be confirmed !!!
                case 'Christchurch-NZ'
                    Header.SiteCode = 'CHR-NZ'; % To be confirmed !!!
                case 'Jade Tianjin'
                    Header.SiteCode = 'JAD-CN';
                case 'Obs Pollmann Leverkusen'
                    Header.SiteCode = 'LEV-DE';
                case 'Mill Ridge_ON_CA'
                    Header.SiteCode = 'MIR-CA'; % To be confirmed !!!
                case 'Mirranook Armidale'
                    Header.SiteCode = 'MIR-AU'; % To be confirmed !!!
                case 'Molines'
                    Header.SiteCode = 'MOL-FR'; % To be confirmed !!!
                case 'Observatoire Astronomique d''Osenbach'
                    Header.SiteCode = 'OAO-FR'; % To be confirmed !!!
                case {'OAF-FR','OAF'}
                    Header.SiteCode = 'OAF-FR';
                case {'38420 Revel','Observatoire Belle Etoile'}
                    Header.SiteCode = 'OBE-FR';
                case {'Observatoire de la Tourbire','Observatoire de la Tourbiere'}
                    Header.SiteCode = 'OTO-FR';
                case {'OHP     ','OHP','Haute Provence','Haute Provence'}
                    Header.SiteCode = 'OHP-FR';
                case 'Pibrac Backyard Observatory'
                    Header.SiteCode = 'PBO-FR';
                case 'Pic du Midi'
                    Header.SiteCode = 'PIC-FR'; % To be confirmed !!!
                case {'Rouen','Rouen   '}
                    Header.SiteCode = 'ROU-FR';
                case 'Saint-Jean Illac'
                    Header.SiteCode = 'SJI-FR'; % To be confirmed !!!
                case {'STA. MARIA DE MONTMAGASTRELL','Sta. Maria M.','Sta. Maria de Montmagastrell'}
                    Header.SiteCode = 'SMM-ES'; % To be confirmed !!!
                case 'San Polo a Mosciano AAF'
                    Header.SiteCode = 'SPM-??'; % To be confirmed !!!
                case {'TAT-HU','Tata'}
                    Header.SiteCode = 'TAT-HU';
                case 'Three Hills Observatory'
                    Header.SiteCode = 'THO-UK'; % To be confirmed !!!
                case {'OTSP2014','Okie-Tex Star Party 2015'}
                    Header.SiteCode = 'TSP-US'; % To be confirmed !!!
                case 'West Challow UK'
                    Header.SiteCode = 'WCO-UK';
                case 'St Sordelin'
                    Header.SiteCode = 'SOR-FR'; % To be confirmed !!!
                case 'Altimira Observatory (G76)'
                    Header.SiteCode = 'G76-US'; % To be confirmed !!!
                case ''
                    Header.SiteCode = ''; % To be confirmed !!!
                case ''
                    Header.SiteCode = ''; % To be confirmed !!!
                case ''
                    Header.SiteCode = ''; % To be confirmed !!!
                otherwise
                    Header.SiteCode = '-------';
            end
            
            % EQUIPMENT data
        case {'BSS_INST','INSTRUME'}
            Header.Instrument = kwd {l,2};
            Instrument = 1;
        case {'BSS_ITRP','SPE_RPOW'}
            Header.Resolution = kwd {l,2};
            Resolution = 1;
    end
    
end

% Manage missing data/keyword in the header
Header.Valid = 1; % Means data is valid

if Exposure == 0 % Without exposure time, we considere the spectrum not valid (TBD: manage other fields ~= '[]' but Exposure == 0)
    Header.Exposure = 0;
    Header.Valid = 0;
end

if WaveOrigin == 0
    Header.WaveOrigin = 0;
end
if Dispersion == 0
    Header.Dispersion = 0;
    Header.WaveMax = 0;
else
    if NAXIS1 == 0
        Header.WaveMax = 0;
    else    
        Header.WaveMax = Header.WaveOrigin + Header.NAXIS1 * Header.Dispersion;
    end
end


if (Object == 0) || (strcmp(Header.Object,''))
    Header.Object = '???';
    Header.Valid = 0; % Without object name, data is invalid (to be confirmed)
end

% Date & Exposure/Duration Time
if Date == 0
    Header.Date = 0;
    Valid = 0; % Without date, data is invalid (to be confirmed)
end

if Header.Valid == 1
    if DateEnd == 0
        if Date == 0
            Header.DateEnd = 0;
        else
            if Exposure == 0
                Header.DateEnd = 0;
            else
                Header.DateEnd = Header.Date + seconds(Header.Exposure);
            end
        end
    end
end

%if ExpTimeTotal == 0
    if Header.Valid == 0
        Header.ExpTimeTotal = 0;
    else
        Header.ExpTimeTotal = seconds(Header.DateEnd - Header.Date);
    end
%end

% Calculated mid JD - TEMPORARY
if (Date == 0) || (Header.Valid == 0)
    Header.CalcJD = 0;
else
    Header.CalcJD = juliandate(Header.Date + seconds(Header.ExpTimeTotal / 2));
end

if JD == 0
    Header.JD = 0;
end

if MidHJD == 0
    Header.MidHJD = 0;
end

% Other fields...
if Observer == 0
    Header.Observer = '???';
    Header.ObserverCode = '???';    
end

if Site == 0
    if strcmp(Header.ObserverCode,'OTH')
        Header.Site = 'Observatoire Belle Etoile';
        Header.SiteCode = 'OBE-FR';
    else
        Header.Site = '???';
        Header.SiteCode = '??????';
    end
end

if Instrument == 0
    Header.Instrument = '????';
end
if strcmp(Header.Instrument,'eshel_6H-101')
    Header.Observer = 'OTH-FR';
end

if Header.Dispersion == 0
    Header.Dispersion = double((Header.WaveMax - Header.WaveOrigin))/double(Header.NAXIS1);
end
if Resolution == 0 % Resolution is actually the Power of Resolution (R)
    % If power of resolution is not provided, assume dispersion is resolution/2.5
    % (Nyquist criteria)
    Header.Resolution = ((Header.WaveMax - Header.WaveOrigin)/2)/(2.5*double(Header.Dispersion));
end

% Calculated Heliocentric RV
if (VHel == 0)
    if (Header.RARad ~= 0)
        if (Header.CalcJD ~= 0)
            [Header.HJD,Header.VHel] = otz_hjd(Header.CalcJD,[Header.RARad Header.DecRad]);
            VHel = 1;
        end
    end
end

for a = 1 : Header.NAXIS1
    Header.Wavelength (a) = Header.WaveOrigin + (a-1) * Header.Dispersion;
     Header.Intensity (a) = Data (1,a);
end

return

% That's all folks!
